@@ -1,3 +1,5 @@
+#![forbid(unsafe_code)]
+
 use crate::{constants, request::Request, Error, Response, Result};
 
 use std::io::Read;
@@ -26,8 +28,7 @@ impl Connection {
         T: Deserialize<'a>,
     {
         self.transformer.get_buffer().resize(size, 0);
-        self.raw_conn
-            .read_exact(&mut self.transformer.get_buffer())?;
+        self.raw_conn.read_exact(self.transformer.get_buffer())?;
 
         // Ignore any trailing bytes to be forward compatible
         Ok(self.transformer.deserialize()?.0)
